# Copyright 2021 The Meson development team
# SPDX-license-identifier: Apache-2.0

__all__ = [
    'ArrayHolder',
    'BooleanHolder',
    'DictHolder',
    'IntegerHolder',
    'RangeHolder',
    'StringHolder',
    'MesonVersionString',
    'MesonVersionStringHolder',
    'DependencyVariableString',
    'DependencyVariableStringHolder',
    'OptionString',
    'OptionStringHolder',
]

from .array import ArrayHolder
from .boolean import BooleanHolder
from .dict import DictHolder
from .integer import IntegerHolder
from .range import RangeHolder
from .string import (
    StringHolder,
    MesonVersionString, MesonVersionStringHolder,
    DependencyVariableString, DependencyVariableStringHolder,
    OptionString, OptionStringHolder,
)
